# Usage

## Installation

```
pip install jovian-data --upgrade
```

## Create dataset

Create a snapshot of a folder to be reused as a dataset

```
jvnd create <folder_name>
```

## List datasets

List all the datasets with versions

```
jvnd list
```

## Mount dataset

Mounts a specific version of dataset

```
jvnd mount <dataset_name/version>
```
